@@ -137,7 +137,7 @@ class DfHelper(ManagedResource):
     def __init__(self, backend="sqlalchemy", **kwargs):
         self.default_config = self.default_config or {}
         kwargs = {**self.default_config.copy(), **kwargs}
-        kwargs.setdefault("auto_sse", True)
+        kwargs.setdefault("auto_sse", False)
         super().__init__(**kwargs)
         self.backend = backend
 
