@@ -39,7 +39,8 @@ class ParquetReader(DfHelper):
     :type fs: fsspec.AbstractFileSystem
     """
     DEFAULT_CONFIG: ClassVar[Dict[str, Any]] = {
-        'backend': 'parquet'
+        'backend': 'parquet',
+        'partition_on': ['partition_date']
     }
     df: Optional[Union[dd.DataFrame, pd.DataFrame]] = None
 
