@@ -30,6 +30,7 @@ class ParquetConfig(BaseModel):
     fs: Optional[fsspec.spec.AbstractFileSystem] = None
     logger: Optional[Logger] = None
     debug: bool = False
+    partition_on: Optional[list[str]] = None          # column name for partitioned datasets
 
     # ---- Derived / runtime fields (lazy) ----
     parquet_full_path: Optional[str] = None      # file or directory
@@ -80,7 +81,7 @@ class ParquetConfig(BaseModel):
             )
 
         # file vs dataset-at-root
-        if self.parquet_filename:
+        if self.parquet_filename and self.partition_on is None:
             self.parquet_full_path = self.ensure_file_extension(
                 posixpath.join(str(self.parquet_storage_path), str(self.parquet_filename)),
                 "parquet",
@@ -174,7 +175,7 @@ class ParquetConfig(BaseModel):
                 self.load_parquet = True
 
         if not self.load_parquet:
-            self.logger.info("Parquet loading disabled by recency policy. Returning empty DataFrame.")
+            self.logger.debug("Parquet loading disabled by recency policy. Returning empty DataFrame.")
             return self._empty_ddf()
 
         # Compile filters
@@ -224,11 +225,32 @@ class ParquetConfig(BaseModel):
 
     # ------------------------- internals -------------------------
 
+
     def _resolve_paths_for_read(self) -> List[str]:
         """
         Builds a list of path patterns for dask.read_parquet.
+        Respects partition_on + start/end date if given.
         """
-        # Date-ranged folders
+        self.logger.debug(f"_resolve_paths_for_read: {self.partition_on}")
+        # Partitioned dataset by column
+        if self.partition_on and self.parquet_start_date and self.parquet_end_date:
+            if not isinstance(self.partition_on, (list, tuple)):
+                parts = [self.partition_on]
+            else:
+                parts = self.partition_on
+
+            start = dt.datetime.strptime(self.parquet_start_date, "%Y-%m-%d").date()
+            end = dt.datetime.strptime(self.parquet_end_date, "%Y-%m-%d").date()
+            days = pd.date_range(start=start, end=end, freq="D").date
+
+            base = self.parquet_storage_path.rstrip("/")
+            result= [
+                f"{base}/{parts[0]}={d.isoformat()}/*.parquet"
+                for d in days
+            ]
+            return result
+
+        # Date-ranged folders (non-partitioned, using FilePathGenerator)
         if self.parquet_folder_list:
             dirs = {self._dirname(p) for p in self.parquet_folder_list}
             return [d.rstrip("/") + "/*.parquet" for d in sorted(dirs)]
