@@ -100,10 +100,10 @@ class SqlAlchemyConnectionConfig(BaseModel):
                 self.engine = wrapper["engine"]
                 wrapper["ref_count"] += 1
                 if self.debug:
-                    self.logger.debug(f"Reusing engine. Ref count: {wrapper['ref_count']}.", extra=self.logger_extra)
+                    self.logger.debug(f"Reusing DB engine. Ref count: {wrapper['ref_count']}.", extra=self.logger_extra)
             else:
                 if self.debug:
-                    self.logger.debug(f"Creating new engine for key: {self._engine_key_instance}", extra=self.logger_extra)
+                    self.logger.debug(f"Creating new DB engine for key: {self._engine_key_instance}", extra=self.logger_extra)
                 try:
                     new_engine = create_engine(
                         self.connection_url,
@@ -122,27 +122,27 @@ class SqlAlchemyConnectionConfig(BaseModel):
                         "active_connections": 0,
                     }
                 except Exception as e:
-                    self.logger.error(f"Failed to create engine: {e}", extra=self.logger_extra)
-                    raise SQLAlchemyError(f"Engine creation failed: {e}") from e
+                    self.logger.error(f"Failed to create DB engine: {e}", extra=self.logger_extra)
+                    raise SQLAlchemyError(f"DB Engine creation failed: {e}") from e
 
     def close(self) -> None:
         if self._closed:
             if self.debug:
-                self.logger.debug("Attempted to close an already-closed config instance.")
+                self.logger.debug("Attempted to close an already-closed DB config instance.")
             return
 
         with _ENGINE_REGISTRY_LOCK:
             key = self._engine_key_instance
             wrapper = _ENGINE_REGISTRY.get(key)
             if not wrapper:
-                self.logger.warning("Attempted to close a config whose engine is not in the registry.", extra=self.logger_extra)
+                self.logger.warning("Attempted to close a DB config whose engine is not in the registry.", extra=self.logger_extra)
             else:
                 wrapper["ref_count"] -= 1
                 if self.debug:
-                    self.logger.debug(f"Closing connection. Ref count now {wrapper['ref_count']}.", extra=self.logger_extra)
+                    self.logger.debug(f"Closing DB connection. Ref count now {wrapper['ref_count']}.", extra=self.logger_extra)
                 if wrapper["ref_count"] <= 0:
                     if self.debug:
-                        self.logger.debug(f"Disposing engine as reference count is zero. Key: {key}", extra=self.logger_extra)
+                        self.logger.debug(f"Disposing DB engine as reference count is zero. Key: {key}", extra=self.logger_extra)
                     try:
                         wrapper["engine"].dispose()
                     finally:
@@ -186,7 +186,7 @@ class SqlAlchemyConnectionConfig(BaseModel):
     @contextmanager
     def managed_connection(self) -> Generator[Any, None, None]:
         if not self.engine:
-            raise RuntimeError("Engine not initialized. Cannot get a connection.")
+            raise RuntimeError("DB Engine not initialized. Cannot get a connection.")
         conn = self.engine.connect()
         try:
             yield conn
