@@ -30,7 +30,7 @@ class SQLAlchemyDask(ManagedResource):
         "NUMERIC": "string", "DECIMAL": "string",
         "BOOLEAN": "boolean",
         "VARCHAR": "string", "CHAR": "string", "TEXT": "string", "UUID": "string",
-        "DATE": "datetime64[ns]", "DATETIME": "datetime64[ns]", "TIMESTAMP": "datetime64[ns]",
+        "DATE": "datetime64[ns, UTC]", "DATETIME": "datetime64[ns, UTC]", "TIMESTAMP": "datetime64[ns, UTC]",
         "TIME": "string",
     }
 
@@ -127,7 +127,9 @@ class SQLAlchemyDask(ManagedResource):
             try:
                 if target_dtype == "datetime64[ns]":
                     # Convert to datetime, coercing errors to NaT
-                    coerced_series = pd.to_datetime(source_series, errors='coerce')
+                    coerced_series = pd.to_datetime(source_series, errors='coerce', utc=True)
+                    # Remove timezone awareness
+                    #coerced_series = coerced_series.dt.tz_localize(None)
                     # Ensure numpy backend by creating a new Series from values
                     output_df[col] = pd.Series(coerced_series.to_numpy(), index=coerced_series.index)
                 elif target_dtype == "Int64":
@@ -170,7 +172,7 @@ class SQLAlchemyDask(ManagedResource):
         self.total_records = total
 
         if total <= 0:
-            self.logger.info(f"Query returned {total} or failed to count records.", extra=self.logger_extra)
+            self.logger.debug(f"Query returned {total} or failed to count records.", extra=self.logger_extra)
             return total, dd.from_pandas(self._meta_df, npartitions=1)
 
         # Simplified to offset pagination as it's the most robust
