@@ -24,6 +24,7 @@ from .manifest_manager import MissingManifestManager
 __all__ = [
     "Logger",
     "ManagedResource",
+
     "ConfigManager",
     "ConfigLoader",
     "DateUtils",
@@ -42,5 +43,5 @@ __all__ = [
     "FsRegistry",
     "DataFromHttpSource",
     "WebDAVClient",
-    "MissingManifestManager"
+    "MissingManifestManager",
 ]
