@@ -14,7 +14,6 @@ from sibi_dst.utils import Logger
 
 # --------- Minimal built-in SSE sink (used when auto_sse=True) ----------
 class _QueueSSE:
-    """Async queue–backed SSE sink: async send/put, async iterator, graceful close."""
     __slots__ = ("q", "_closed")
 
     def __init__(self) -> None:
@@ -33,7 +32,7 @@ class _QueueSSE:
             await self.q.put({"event": "__close__", "data": ""})
 
     def close(self) -> None:
-        pass
+        self._closed = True
 
     async def __aiter__(self):
         while True:
@@ -45,26 +44,15 @@ class _QueueSSE:
 
 # ------------------------------ Base class ------------------------------
 class ManagedResource(abc.ABC):
-    """
-    Owns a logger and optional fsspec filesystem. Can emit SSE events via:
-    - an async emitter callable:  await emitter(event, data)
-    - a sink exposing async send(event, data) or async put(item)
-    If neither is provided and auto_sse=True, a queue-backed sink is created eagerly.
-    Thread-safe lifecycle, CM support, GC finalizer.
-    """
-
     __slots__ = (
-        # config
         "verbose", "debug", "_log_cleanup_errors",
-        # logger
         "logger", "_owns_logger",
-        # fs
         "fs", "_fs_factory", "_owns_fs",
-        # sse
         "_sse", "_sse_factory", "_owns_sse",
         "_emitter", "_auto_sse",
-        # lifecycle
-        "_is_closed", "_closing", "_close_lock", "_finalizer"
+        "_is_closed", "_closing",
+        "_close_lock", "_aclose_lock",
+        "_finalizer",
     )
 
     def __init__(
@@ -74,28 +62,25 @@ class ManagedResource(abc.ABC):
         debug: bool = False,
         log_cleanup_errors: bool = True,
         logger: Optional[Logger] = None,
-        # filesystem
         fs: Optional[fsspec.AbstractFileSystem] = None,
         fs_factory: Optional[Callable[[], fsspec.AbstractFileSystem]] = None,
-        # SSE
         emitter: Optional[Callable[[str, Dict[str, Any]], Awaitable[None]]] = None,
         emitter_factory: Optional[Callable[[], Callable[[str, Dict[str, Any]], Awaitable[None]]]] = None,
         sse: Optional[object] = None,
         sse_factory: Optional[Callable[[], object]] = None,
-        auto_sse: bool = False,           # eager auto-create if no emitter/sink is supplied
+        auto_sse: bool = False,
         **_: object,
     ) -> None:
-        # flags
         self.verbose = verbose
         self.debug = debug
         self._log_cleanup_errors = log_cleanup_errors
 
-        # lifecycle
         self._is_closed = False
         self._closing = False
         self._close_lock = threading.RLock()
+        self._aclose_lock = asyncio.Lock()
 
-        # logger
+        # ---------- Logger ----------
         if logger is None:
             self.logger = Logger.default_logger(logger_name=self.__class__.__name__)
             self._owns_logger = True
@@ -105,7 +90,7 @@ class ManagedResource(abc.ABC):
             self.logger = logger
             self._owns_logger = False
 
-        # fs
+        # ---------- FS ----------
         self.fs: Optional[fsspec.AbstractFileSystem] = None
         self._fs_factory = None
         self._owns_fs = False
@@ -119,7 +104,7 @@ class ManagedResource(abc.ABC):
             self._fs_factory = fs_factory
             self._owns_fs = True
 
-        # sse / emitter
+        # ---------- SSE ----------
         self._sse: Optional[object] = None
         self._sse_factory: Optional[Callable[[], object]] = None
         self._owns_sse = False
@@ -140,18 +125,17 @@ class ManagedResource(abc.ABC):
             self._sse_factory = sse_factory
             self._owns_sse = True
 
-        # EAGER auto-SSE: create sink+emitter now if none supplied
         if self._auto_sse and self._sse is None and self._emitter is None and self._sse_factory is None:
             self._create_auto_sse()
 
-        # GC finalizer
+        # ---------- Finalizer ----------
         self._finalizer = weakref.finalize(self, self._finalize_static, weakref.ref(self))
 
         if self.debug:
             with contextlib.suppress(Exception):
                 self.logger.debug("Initialized %s %s", self.__class__.__name__, repr(self))
 
-    # ---------- Introspection ----------
+    # ---------- Properties ----------
     @property
     def closed(self) -> bool:
         return self._is_closed
@@ -178,14 +162,13 @@ class ManagedResource(abc.ABC):
         return (f"<{self.__class__.__name__} debug={self.debug} verbose={self.verbose} "
                 f"log_cleanup_errors={self._log_cleanup_errors} fs={fs_status} sse={sse_status}>")
 
-    # ---------- Subclass hooks ----------
+    # ---------- Hooks ----------
     def _cleanup(self) -> None:
         return
 
     async def _acleanup(self) -> None:
         return
 
-    # ---------- Guards ----------
     def _assert_open(self) -> None:
         if self._is_closed or self._closing:
             raise RuntimeError(f"{self.__class__.__name__} is closed")
@@ -222,10 +205,10 @@ class ManagedResource(abc.ABC):
 
     # ---------- SSE ----------
     def _create_auto_sse(self) -> None:
-        # internal helper: create queue sink + emitter, mark as owned
         sink = _QueueSSE()
         self._sse = sink
-        self._owns_sse = True
+        we_own = True
+        self._owns_sse = we_own
         self._emitter = self._build_emitter(sink)
 
     def set_sse_factory(self, factory: Optional[Callable[[], object]]) -> None:
@@ -256,7 +239,6 @@ class ManagedResource(abc.ABC):
             return None
 
     def get_sse(self) -> Optional[object]:
-        """Public getter; creates the sink if auto_sse/factory available."""
         return self._ensure_sse()
 
     def _build_emitter(self, sink: object) -> Callable[[str, Dict[str, Any]], Awaitable[None]]:
@@ -286,7 +268,6 @@ class ManagedResource(abc.ABC):
         raise TypeError(f"{self.__class__.__name__}: SSE sink must expose send(event, data) or put(item)")
 
     async def emit(self, event: str, **data: Any) -> None:
-        """No-op during closing/closed or if no emitter is configured."""
         if self._is_closed or self._closing:
             return
         if self._emitter is None:
@@ -318,7 +299,7 @@ class ManagedResource(abc.ABC):
         close = getattr(obj, "close", None)
         if callable(close):
             with contextlib.suppress(Exception):
-                close()
+                await asyncio.to_thread(close)
 
     def _shutdown_logger(self) -> None:
         if self._owns_logger:
@@ -350,13 +331,22 @@ class ManagedResource(abc.ABC):
         self._emitter = None
         self._shutdown_logger()
 
-    # ---------- Public lifecycle (sync) ----------
+    # ---------- Public lifecycle ----------
     @final
     def close(self, *, suppress_errors: bool = False) -> None:
         with self._close_lock:
             if self._is_closed or self._closing:
                 return
             self._closing = True
+            # optional subclass hook
+            maybe_close = getattr(self, "_close_obj", None)
+            if callable(maybe_close):
+                try:
+                    maybe_close()
+                except Exception:
+                    if not suppress_errors:
+                        raise
+
         try:
             self._cleanup()
         except Exception:
@@ -374,7 +364,6 @@ class ManagedResource(abc.ABC):
                 with contextlib.suppress(Exception):
                     self.logger.debug("Component %s closed.", self.__class__.__name__)
 
-    # ---------- Public lifecycle (async) ----------
     @final
     async def aclose(
         self,
@@ -382,29 +371,40 @@ class ManagedResource(abc.ABC):
         suppress_errors: bool = False,
         run_sync_cleanup_if_missing: bool = False,
     ) -> None:
-        with self._close_lock:
-            if self._is_closed or self._closing:
-                return
-            self._closing = True
-        try:
-            if run_sync_cleanup_if_missing and (type(self)._acleanup is ManagedResource._acleanup):
-                await asyncio.to_thread(self._cleanup)
-            else:
-                await self._acleanup()
-        except Exception:
-            if self._log_cleanup_errors:
-                with contextlib.suppress(Exception):
-                    self.logger.error("Error during %s._acleanup()", self.__class__.__name__, exc_info=self.debug)
-            if not suppress_errors:
-                raise
-        finally:
+        async with self._aclose_lock:
             with self._close_lock:
-                self._is_closed = True
-                self._closing = False
-            await self._shutdown_owned_resources_async()
-            if self.debug:
-                with contextlib.suppress(Exception):
-                    self.logger.debug("Async component %s closed.", self.__class__.__name__)
+                if self._is_closed or self._closing:
+                    return
+                self._closing = True
+
+            try:
+                # optional subclass hook with distinct name to avoid clashing with helper
+                maybe_async_close = getattr(self, "_custom_aclose_obj", None)
+                if asyncio.iscoroutinefunction(maybe_async_close):
+                    await maybe_async_close()
+                elif callable(maybe_async_close):
+                    await asyncio.to_thread(maybe_async_close)
+
+                if run_sync_cleanup_if_missing and (type(self)._acleanup is ManagedResource._acleanup):
+                    await asyncio.to_thread(self._cleanup)
+                else:
+                    await self._acleanup()
+            except Exception:
+                if self._log_cleanup_errors:
+                    with contextlib.suppress(Exception):
+                        self.logger.error(
+                            "Error during %s._acleanup()", self.__class__.__name__, exc_info=self.debug
+                        )
+                if not suppress_errors:
+                    raise
+            finally:
+                with self._close_lock:
+                    self._is_closed = True
+                    self._closing = False
+                await self._shutdown_owned_resources_async()
+                if self.debug:
+                    with contextlib.suppress(Exception):
+                        self.logger.debug("Async component %s closed.", self.__class__.__name__)
 
     # ---------- Context managers ----------
     @final
@@ -425,7 +425,7 @@ class ManagedResource(abc.ABC):
         await self.aclose()
         return False
 
-    # ---------- Finalizer (silent) ----------
+    # ---------- Finalizer ----------
     @staticmethod
     def _finalize_static(ref: "weakref.ReferenceType[ManagedResource]") -> None:
         obj = ref()
@@ -439,5 +439,4 @@ class ManagedResource(abc.ABC):
                 with contextlib.suppress(Exception):
                     obj._shutdown_owned_resources_sync()
         except Exception:
-            pass
-
+            pass
\ No newline at end of file
