@@ -1,16 +1,20 @@
-from .base_parquet_artifact import BaseParquetArtifact
+from __future__ import annotations
+from .base_attacher import make_attacher, AttachmentMaker
 from .base_data_cube import BaseDataCube
-from .base_attacher import make_attacher
+from .base_parquet_artifact import BaseParquetArtifact
 from .base_parquet_reader import BaseParquetReader
-from .hybrid_data_loader import HybridDataLoader
 from .base_pipeline import BasePipeline
+from .base_pipeline_template import PipelineTemplate
+from .hybrid_data_loader import HybridDataLoader
 
 __all__ = [
     "BaseDataCube",
     "BaseParquetArtifact",
+    "AttachmentMaker",
     "make_attacher",
     "BaseParquetReader",
     "HybridDataLoader",
     "BasePipeline",
+    "PipelineTemplate",
 ]
 
