@@ -1,12 +1,13 @@
 from __future__ import annotations
 
-from typing import Union, List, Dict, Any, Iterable
+from typing import Union, List, Any, Iterable
 
 import dask.dataframe as dd
 import pandas as pd
 
 from .log_utils import Logger
 
+UTC_DATETIME_DTYPE = "datetime64[ns, UTC]"
 
 class DataUtils:
     """
@@ -190,12 +191,55 @@ class DataUtils:
 
     @staticmethod
     def convert_to_datetime_dask(df: dd.DataFrame, date_fields: Iterable[str]) -> dd.DataFrame:
-        """
-        Partition-wise datetime coercion with errors='coerce'.
-        """
+        """Convert specified columns to UTC-aware datetime64[ns, UTC]."""
+
+        def _to_pandas_datetime(part: pd.DataFrame) -> pd.DataFrame:
+            part = part.copy()
+            for col in date_fields:
+                if col not in part.columns:
+                    continue
+                part[col] = pd.to_datetime(part[col], errors="coerce", utc=False)
+                dtype = part[col].dtype
+                if isinstance(dtype, pd.DatetimeTZDtype):
+                    # already timezone-aware → normalize to UTC
+                    part[col] = part[col].dt.tz_convert("UTC")
+                else:
+                    # naive → localize to UTC
+                    part[col] = part[col].dt.tz_localize("UTC")
+            return part
+
+        meta = df._meta.copy()
         for col in date_fields:
-            if col in df.columns:
-                df[col] = df[col].map_partitions(
-                    pd.to_datetime, errors="coerce", meta=(col, "datetime64[ns]")
-                )
-        return df
\ No newline at end of file
+            if col in meta.columns:
+                meta[col] = pd.Series([], dtype=UTC_DATETIME_DTYPE)
+        return df.map_partitions(_to_pandas_datetime, meta=meta)
+
+    @staticmethod
+    def enforce_pandas_dtypes(df: dd.DataFrame) -> dd.DataFrame:
+        """Convert all PyArrow columns to pandas equivalents with UTC consistency."""
+
+        def _convert_partition(part: pd.DataFrame) -> pd.DataFrame:
+            part = part.copy()
+            for col in part.columns:
+                dtype_name = part[col].dtype.name
+                if dtype_name.startswith("timestamp[ns][pyarrow]"):
+                    part[col] = pd.to_datetime(part[col], errors="coerce", utc=True)
+                elif "string" in dtype_name:
+                    part[col] = (
+                        part[col].astype(str).replace("None", None).astype("object")
+                    )
+                elif dtype_name == "bool":
+                    part[col] = part[col].astype("boolean")
+            return part
+
+        meta = df._meta.copy()
+        for col in meta.columns:
+            dtype_name = meta[col].dtype.name
+            if dtype_name.startswith("timestamp[ns][pyarrow]"):
+                meta[col] = pd.Series([], dtype=UTC_DATETIME_DTYPE)
+            elif dtype_name == "string":
+                meta[col] = pd.Series([], dtype="object")
+            elif dtype_name == "bool":
+                meta[col] = pd.Series([], dtype="boolean")
+
+        return df.map_partitions(_convert_partition, meta=meta)
