@@ -8,8 +8,9 @@ from .log_utils import Logger
 
 
 class FileUtils:
-    def __init__(self, logger=None):
-        self.logger = logger or Logger.default_logger(logger_name=self.__class__.__name__)
+    def __init__(self, **kwargs):
+        self.logger = kwargs.get('logger', Logger.default_logger(logger_name=self.__class__.__name__))
+        self.debug = kwargs.get('debug', False)
 
     @staticmethod
     def ensure_directory_exists(directory_path, clear_existing=False):
