@@ -146,7 +146,7 @@ class MissingManifestManager:
                 else:
                     self.fs.copy(temp_path, self.manifest_path)
                     self.fs.rm_file(temp_path)
-                self.logger.info(f"Wrote manifest to {self.manifest_path}")
+                self.logger.debug(f"Wrote manifest to {self.manifest_path}")
             except Exception as e:
                 self.logger.error(f"Failed to write or move manifest: {e}")
                 # not re-raising to avoid breaking the ETL run
@@ -183,7 +183,7 @@ class MissingManifestManager:
                         self.fs.rm_file(f_path)
                     else:
                         self.fs.rm(f_path, recursive=False)
-                    self.logger.info(f"Deleted orphaned file: {f_path}")
+                    self.logger.debug(f"Deleted orphaned file: {f_path}")
                 except Exception as e:
                     self.logger.warning(f"Failed to delete orphaned temp file '{f_path}': {e}")
         except Exception as e:
