@@ -71,6 +71,7 @@ class ParquetSaver(ManagedResource):
             max_delete_workers: int = 8,
             write_gate_max: int = 2,
             write_gate_key: Optional[str] = None,
+            partition_on: Optional[list[str]] = None,
             **kwargs: Any,
     ):
         super().__init__(**kwargs)
@@ -93,6 +94,7 @@ class ParquetSaver(ManagedResource):
         self.max_delete_workers = max(1, int(max_delete_workers))
         self.write_gate_max = max(1, int(write_gate_max))
         self.write_gate_key = (write_gate_key or self.parquet_storage_path).rstrip("/")
+        self.partition_on = partition_on
 
         # Fix: Remove deprecated coerce_timestamps parameter
         self.pyarrow_args.setdefault("compression", "zstd")
@@ -103,7 +105,18 @@ class ParquetSaver(ManagedResource):
 
     # ---------- public API ----------
     def save_to_parquet(self, output_directory_name: str = "default_output", overwrite: bool = True) -> str:
-        target_path = f"{self.parquet_storage_path}/{output_directory_name}".rstrip("/")
+        """
+        Save the Dask DataFrame to Parquet. If partition_on is provided, write as a
+        partitioned dataset without overwriting earlier partitions.
+        """
+        # Always treat as a directory target
+        if self.partition_on:
+            overwrite = False
+            # we override the output_directory_name and overwrite setting to avoid confusion since dask will (re) create subdirs
+            # Partitioned dataset → write directly to root directory
+            target_path = self.parquet_storage_path.rstrip("/")
+        else:
+            target_path = f"{self.parquet_storage_path}/{output_directory_name}".rstrip("/")
 
         sem = get_write_sem(self.write_gate_key, self.write_gate_max)
         with sem:
@@ -111,7 +124,7 @@ class ParquetSaver(ManagedResource):
                 self._clear_directory_safely(target_path)
             self.fs.mkdirs(target_path, exist_ok=True)
 
-            # Define a pyarrow schema and coerce the Dask frame to match it.
+            # Enforce schema before write
             schema = self._define_schema()
             ddf = self._coerce_ddf_to_schema(self.df_result, schema)
 
@@ -128,25 +141,25 @@ class ParquetSaver(ManagedResource):
                 pa.set_cpu_count(self.arrow_cpu)
 
             try:
+                params = {
+                    "path": target_path,
+                    "engine": "pyarrow",
+                    "filesystem": self.fs,
+                    "write_index": self.write_index,
+                    "write_metadata_file": self.write_metadata_file,
+                    **self.pyarrow_args,
+                }
+                self.partition_on = self.partition_on if isinstance(self.partition_on, list) else None
+                if self.partition_on:
+                    params["partition_on"] = self.partition_on
+
                 with self._local_dask_pool():
-                    ddf.to_parquet(
-                        path=target_path,
-                        engine="pyarrow",
-                        schema=schema,
-                        overwrite=False,
-                        filesystem=self.fs,
-                        write_index=self.write_index,
-                        write_metadata_file=self.write_metadata_file,
-                        **self.pyarrow_args,
-                    )
+                    ddf.to_parquet(**params)
             finally:
                 if old_arrow_cpu is not None:
                     pa.set_cpu_count(old_arrow_cpu)
 
-        self.logger.info(
-            f"Parquet dataset written: {target_path}",
-            extra=self.logger_extra,
-        )
+        self.logger.info(f"Parquet dataset written: {target_path}", extra=self.logger_extra)
         return target_path
 
     @contextmanager
